@@ -1,5 +1,5 @@
 /*  Arg_parser - POSIX/GNU command line argument parser. (C version)
-    Copyright (C) 2006-2017 Antonio Diaz Diaz.
+    Copyright (C) 2006-2019 Antonio Diaz Diaz.
 
     This program is free software: you have unlimited permission to
     copy, distribute and modify it.
@@ -22,17 +22,29 @@
 #include "carg_parser.h"
 
 
-static const char * const Program_name = "Arg_parser";
 static const char * const program_name = "arg_parser";
-static const char * const program_year = "2017";
+static const char * const program_year = "2019";
 static const char * invocation_name = 0;
 
 
 void show_help( const char verbose )
   {
-  printf( "%s - POSIX/GNU command line argument parser. (C version)\n", Program_name );
-  printf( "See the source file 'cmain.c' to learn how to use %s in\n", Program_name );
-  printf( "your own programs.\n"
+  printf( "Arg_parser - POSIX/GNU command line argument parser. (C version)\n"
+          "\nArg_parser is an argument parser that follows POSIX and GNU conventions for\n"
+          "command line arguments. There exist C++ and C versions of Arg_parser. The\n"
+          "C++ version is implemented as a C++ class, while the C version is\n"
+          "implemented as a single struct plus associated functions. Both are simpler,\n"
+          "easier to use, and safer than 'getopt_long'.\n"
+          "\nFor maximum stability, Arg_parser is self-contained. It extracts all the\n"
+          "information it needs from its arguments to avoid refering to them later.\n"
+          "This avoids index-out-of-bounds errors.\n"
+          "\nArg_parser does not modify its arguments, nor uses any global variables. So\n"
+          "you may create more than one parser in your program if you need or want to.\n"
+          "\nThe C++ version of Arg_parser can also parse options from configuration\n"
+          "files.\n"
+          "\nTo use Arg_parser in your own programs simply copy the files 'carg_parser.h'\n"
+          "and 'carg_parser.c' in your source tree. See also the file 'cmain.c' for an\n"
+          "example of use.\n"
           "\nUsage: %s [options]\n", invocation_name );
   printf( "\nOptions:\n"
           "  -h, --help                   display this help and exit\n"
@@ -67,11 +79,9 @@ void show_version()
 void show_error( const char * const msg, const int errcode, const char help )
   {
   if( msg && msg[0] )
-    {
-    fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 ) fprintf( stderr, ": %s", strerror( errcode ) );
-    fputc( '\n', stderr );
-    }
+    fprintf( stderr, "%s: %s%s%s\n", program_name, msg,
+             ( errcode > 0 ) ? ": " : "",
+             ( errcode > 0 ) ? strerror( errcode ) : "" );
   if( help )
     fprintf( stderr, "Try '%s --help' for more information.\n",
              invocation_name );
